# python script to produce graphs of annual average CO2 level in ppm
# from 1850-2017

import urllib
from hashlib import sha256
import re
import numpy as np
import matplotlib.pyplot as plt

# sources
url1 = 'https://data.giss.nasa.gov/modelforce/ghgases/Fig1A.ext.txt'

# get source
file1 = urllib.urlretrieve(url1, 'file1.txt')
with open('file1.txt') as f:
    content1 = f.read()
hash1 = sha256(content1).hexdigest()
if hash1 != '42e383d871c43f067b6de6ae34e26a1768eb7939abb87fa81bf46f926633701f':
    print("error! file hashes do not match:", url1)
    print("SHA2-256 hash should be: 42e383d871c43f067b6de6ae34e26a1768eb7939abb87fa81bf46f926633701f")
    print("but is: ", hash1)

# parse file
d = dict()
for line in content1.split('\n'):
    if len(line) != 0 and line[0] == '#':
        continue
    words = line.split(' ')
    wds = [w for w in words if w != '']
    for i in range(0, len(wds)):
        if re.match('^[12][0-9]{3}$',wds[i]) != None and wds[i] != '1000':
            d[int(wds[i])] = float(wds[i+1])

# to numpy
data = np.array(list(sorted(d.items())))

# plot
plt.plot(data[...,0], data[...,1], '-', linewidth=2.0)
plt.xlabel('year')
plt.ylabel('parts per million')
plt.title('atmospheric CO$_2$ content')
plt.grid(True)
plt.axis([1850, 2020, 0, 210000])
plt.savefig('co2_absolute.svg')
#plt.show()
plt.axis([1850, 2020, 250, 450])
plt.savefig('co2_relative.svg')
#plt.show()

